==> cinder_16.4.2.orig.tar.gz: cinder-16.4.2/cinder/api/schemas/volume_type_access.py <==
# Copyright (C) 2017 NTT DATA
# All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

"""
Schema for V3 volume type access API.

"""

from cinder.api.validation import parameter_types

add_project_access = {
    'type': 'object',
    'properties': {
        'type': 'object',
        'addProjectAccess': {
            'type': 'object',
            'properties': {
                'project': parameter_types.uuid,
            },
            'required': ['project'],
            'additionalProperties': False,
        },
    },
    'required': ['addProjectAccess'],
    'additionalProperties': False,
}


remove_project_access = {
    'type': 'object',
    'properties': {
        'type': 'object',
        'removeProjectAccess': {
            'type': 'object',
            'properties': {
                'project': parameter_types.uuid,
            },
            'required': ['project'],
            'additionalProperties': False,
        },
    },
    'required': ['removeProjectAccess'],
    'additionalProperties': False,
}

==> cinder_27.0.0.orig.tar.gz: cinder-27.0.0/cinder/api/schemas/volume_type_access.py <==
# Copyright (C) 2017 NTT DATA
# All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

"""
Schema for V3 volume type access API.

"""

add_project_access = {
    'type': 'object',
    'properties': {
        'type': 'object',
        'addProjectAccess': {
            'type': 'object',
            'properties': {
                'project': {'type': 'string',
                            'minLength': 1, 'maxLength': 255},
            },
            'required': ['project'],
            'additionalProperties': False,
        },
    },
    'required': ['addProjectAccess'],
    'additionalProperties': False,
}


remove_project_access = {
    'type': 'object',
    'properties': {
        'type': 'object',
        'removeProjectAccess': {
            'type': 'object',
            'properties': {
                'project': {'type': 'string',
                            'minLength': 1, 'maxLength': 255},
            },
            'required': ['project'],
            'additionalProperties': False,
        },
    },
    'required': ['removeProjectAccess'],
    'additionalProperties': False,
}
